@@ -23,12 +23,12 @@ from horizon import tables
 
 from openstack_dashboard import policy
 from tacker_horizon.openstack_dashboard import api
+from tackerclient.common.exceptions import NotFound
 
 
 class VNFManagerItem(object):
-
     def __init__(self, name, description, vnfs, vim, status,
-                 stack_status, stack_id):
+                 stack_status, stack_id, error_reason):
         self.name = name
         self.description = description
         self.vnfs = vnfs
@@ -36,6 +36,7 @@ class VNFManagerItem(object):
         self.status = status
         self.stack_status = stack_status
         self.id = stack_id
+        self.error_reason = error_reason
 
 
 class VNFManagerItemList(object):
@@ -94,8 +95,8 @@ class VNFUpdateRow(tables.Row):
         try:
             # stack = api.heat.stack_get(request, stack_id)
             # if stack.stack_status == 'DELETE_COMPLETE':
-                # returning 404 to the ajax call removes the
-                # row from the table on the ui
+            # returning 404 to the ajax call removes the
+            # row from the table on the ui
             #    raise Http404
             item = VNFManagerItemList.get_obj_given_stack_id(vnf_id)
             vnf_instance = api.tacker.get_vnf(request, vnf_id)
@@ -123,15 +124,16 @@ class VNFUpdateRow(tables.Row):
                 # Add an item entry
                 item = VNFManagerItem(vnf['name'], vnf_desc_str,
                                       vnf_services_str, str(vim),
-                                      vnf['status'], vnf['status'], vnf['id'])
+                                      vnf['status'], vnf['status'], vnf['id'],
+                                      vnf['error_reason'])
             else:
                 item.description = vnf_desc_str
                 item.vnfs = vnf_services_str
                 item.status = vnf['status']
                 item.stack_status = vnf['status']
             return item
-        except Http404:
-            raise
+        except (Http404, NotFound):
+            raise Http404
         except Exception as e:
             messages.error(request, e)
             raise
@@ -234,6 +236,7 @@ class VNFManagerTable(tables.DataTable):
                                        u"Check Failed")),
     )
     name = tables.Column("name",
+                         link="horizon:nfv:vnfmanager:detail",
                          verbose_name=_("VNF Name"))
     description = tables.Column("description",
                                 verbose_name=_("Description"))
@@ -247,6 +250,8 @@ class VNFManagerTable(tables.DataTable):
     stack_status = tables.Column("stack_status",
                                  verbose_name=_("Status"),
                                  display_choices=STACK_STATUS_DISPLAY_CHOICES)
+    error_reason = tables.Column("error_reason",
+                                 verbose_name=_("Error Reason"))
 
     class Meta(object):
         name = "vnfmanager"
